| Title: | Run Multiple Scenarios of the Daedalus Model |
|---|---|
| Description: | Run multiple pandemic response scenarios using the daedalus package and access epidemiological and economic outcomes. |
| Authors: | Pratik Gupte [aut, cre] (ORCID: <https://orcid.org/0000-0001-5294-7819>), Abdul Latif Jameel Institute for Disease and Emergency Analytics [fnd], Imperial College of Science, Technology and Medicine [cph, fnd] |
| Maintainer: | Pratik Gupte <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.6 |
| Built: | 2026-05-11 10:10:23 UTC |
| Source: | https://github.com/jameel-institute/daedalus.compare |
Calculate an interval
ci(x, level = 95)ci(x, level = 95)
x |
A numeric vector. |
level |
The interval level as a numeric vector with values in the range
|
A numeric vector of the same length as level.
Get cost data from DAEDALUS scenarios
get_cost_data(dt, disease_tags = "default", format = c("long", "wide"))get_cost_data(dt, disease_tags = "default", format = c("long", "wide"))
dt |
A |
disease_tags |
A character vector giving names for replicates within each scenario. |
format |
A string for whether the data should be returned in |
A <data.frame> summarising epidemic costs over the timeframe of the
modelled epidemics.
A <data.frame> of the costs for each model scenario.
Get economic cost details from an output data.table
get_econ_cost_data(dt)get_econ_cost_data(dt)
dt |
A |
A <data.frame> summarising economic costs over the timeframe of the
modelled epidemics, broken down into costs due to restrictions and illness-
related absences.
Get epidemiological curves from model data
get_epicurve_data(dt, disease_tags = "default", format = c("long", "wide"))get_epicurve_data(dt, disease_tags = "default", format = c("long", "wide"))
dt |
A |
disease_tags |
A character vector giving names for replicates within each scenario. |
format |
A string for whether the data should be returned in |
A <data.frame> of individuals in each epidemiological compartments
over the timeframe of the modelled epidemics.
Get summary data from DAEDALUS scenarios
get_summary_data(dt, disease_tags, format = c("long", "wide"), ...)get_summary_data(dt, disease_tags, format = c("long", "wide"), ...)
dt |
A |
disease_tags |
A character vector giving names for replicates within each scenario. |
format |
A string for whether the data should be returned in |
... |
Additional arguments passed to |
A <data.frame> summarising epidemiological outcomes: cumulative
infections, deaths, and hospitalisations over the timeframe of the modelled
epidemics.
<daedalus_infection>s from parameter distributionsGenerate multiple <daedalus_infection>s from parameter distributions
make_infection_samples( name, param_distributions, param_ranges = NULL, samples = 100 )make_infection_samples( name, param_distributions, param_ranges = NULL, samples = 100 )
name |
An infection name from among |
param_distributions |
A named list of |
param_ranges |
An optional named list of two-element vectors, giving the
ranges to which samples drawn using |
samples |
The number of samples to generate. |
A list of <daedalus_infection> objects.
# make 10 infection objects varying in R0, with a skewed distribution # scaled between 1.0 and 2.0 make_infection_samples( "influenza_2009", samples = 3, list( r0 = distributional::dist_beta(2, 5) ), list( r0 = c(0.1, 0.2) ) )# make 10 infection objects varying in R0, with a skewed distribution # scaled between 1.0 and 2.0 make_infection_samples( "influenza_2009", samples = 3, list( r0 = distributional::dist_beta(2, 5) ), list( r0 = c(0.1, 0.2) ) )
Names of age-varying infection parameters
NAMES_VECTOR_INF_PARAMSNAMES_VECTOR_INF_PARAMS
An object of class character of length 4.
Run multiple DAEDALUS scenarios
run_scenarios( country, infection, response_strategy = NULL, vaccination_strategy = NULL, time_end = 100, initial_state_manual = NULL )run_scenarios( country, infection, response_strategy = NULL, vaccination_strategy = NULL, time_end = 100, initial_state_manual = NULL )
country |
A country or territory object of class |
infection |
A list of |
response_strategy |
A time-limited response strategy specified as a
single |
vaccination_strategy |
A vaccination strategy specified as a
single |
time_end |
A vector of integer-ish numbers giving the durations over
which to run scenarios. Each scenario is run for each |
initial_state_manual |
An optional named list with the names
|
A <data.table>, with data held in list-columns.